@@ -1,8 +1,9 @@
-from typing import Optional
+from typing import Optional, Mapping
 
 from kognic.io.model.input.abstract import BaseInputWithIMUData
 from kognic.io.model.input.lidars_and_cameras.frame import Frame
 from kognic.io.model.input.metadata.metadata import AllowedMetaData
+from kognic.io.model.input.resources.resource import Resource
 from kognic.io.model.input.sensor_specification import SensorSpecification
 
 
@@ -11,4 +12,8 @@ class LidarsAndCameras(BaseInputWithIMUData):
     frame: Frame
     calibration_id: str
     sensor_specification: Optional[SensorSpecification] = None
-    metadata: AllowedMetaData
+    metadata: AllowedMetaData = dict()
+
+    @property
+    def resources(self) -> Mapping[str, Resource]:
+        return self.frame.resources
