@@ -3,7 +3,7 @@ from typing import List, Mapping, Union, Optional
 from kognic.io.model import UnixTimestampNs
 from kognic.io.model.ego import EgoVehiclePose
 from kognic.io.model.input.abstract.sequence_frame import SequenceFrame
-from kognic.io.model.input.resources import PointCloud, Image, VideoFrame
+from kognic.io.model.input.resources import PointCloud
 
 
 class Frame(SequenceFrame):
@@ -11,3 +11,7 @@ class Frame(SequenceFrame):
     ego_vehicle_pose: Optional[EgoVehiclePose] = None
     metadata: Mapping[str, Union[int, float, str, bool]] = {}
     unix_timestamp: Optional[UnixTimestampNs] = None
+
+    @property
+    def resources(self) -> Mapping[str, PointCloud]:
+        return {p.resource_id: p for p in self.point_clouds}
